==> dbservice-1.0.0-20160519.071431-8879-sources.jar: com/xunlei/channel/db/pojo/UserCannotPayOrders.java <==
package com.xunlei.channel.db.pojo;

/**
 * Created by ouyangjixin on 2016/5/18.
 */
public class UserCannotPayOrders extends AbstractBaseEntity{

    private String orderId;
    private String phone;
    private double orderAmount;
    private String bizNo;

    private String payType;
    private String xunleiId;
    private String userShow;

    private String xunleiPayId;
    private String orderTime;
    private String errorCode;
    private String errorMsg;
    private String extension1;

    private String extension2;
    private String extension3;

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public double getOrderAmount() {
        return orderAmount;
    }

    public void setOrderAmount(double orderAmount) {
        this.orderAmount = orderAmount;
    }

    public String getBizNo() {
        return bizNo;
    }

    public void setBizNo(String bizNo) {
        this.bizNo = bizNo;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getXunleiId() {
        return xunleiId;
    }

    public void setXunleiId(String xunleiId) {
        this.xunleiId = xunleiId;
    }

    public String getUserShow() {
        return userShow;
    }

    public void setUserShow(String userShow) {
        this.userShow = userShow;
    }

    public String getXunleiPayId() {
        return xunleiPayId;
    }

    public void setXunleiPayId(String xunleiPayId) {
        this.xunleiPayId = xunleiPayId;
    }

    public String getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(String orderTime) {
        this.orderTime = orderTime;
    }

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getExtension1() {
        return extension1;
    }

    public void setExtension1(String extension1) {
        this.extension1 = extension1;
    }

    public String getExtension2() {
        return extension2;
    }

    public void setExtension2(String extension2) {
        this.extension2 = extension2;
    }

    public String getExtension3() {
        return extension3;
    }

    public void setExtension3(String extension3) {
        this.extension3 = extension3;
    }

    @Override
    public String toString() {
        return "UserCannotPayOrders{" +
                "orderId='" + orderId + '\'' +
                ", phone='" + phone + '\'' +
                ", orderAmount=" + orderAmount +
                ", bizNo='" + bizNo + '\'' +
                ", payType='" + payType + '\'' +
                ", xunleiId='" + xunleiId + '\'' +
                ", userShow='" + userShow + '\'' +
                ", xunleiPayId='" + xunleiPayId + '\'' +
                ", orderTime='" + orderTime + '\'' +
                ", errorCode='" + errorCode + '\'' +
                ", errorMsg='" + errorMsg + '\'' +
                ", extension1='" + extension1 + '\'' +
                ", extension2='" + extension2 + '\'' +
                ", extension3='" + extension3 + '\'' +
                '}';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        UserCannotPayOrders that = (UserCannotPayOrders) o;

        if (Double.compare(that.orderAmount, orderAmount) != 0) return false;
        if (orderId != null ? !orderId.equals(that.orderId) : that.orderId != null) return false;
        if (phone != null ? !phone.equals(that.phone) : that.phone != null) return false;
        if (bizNo != null ? !bizNo.equals(that.bizNo) : that.bizNo != null) return false;
        if (payType != null ? !payType.equals(that.payType) : that.payType != null) return false;
        if (xunleiId != null ? !xunleiId.equals(that.xunleiId) : that.xunleiId != null) return false;
        if (userShow != null ? !userShow.equals(that.userShow) : that.userShow != null) return false;
        if (xunleiPayId != null ? !xunleiPayId.equals(that.xunleiPayId) : that.xunleiPayId != null) return false;
        if (orderTime != null ? !orderTime.equals(that.orderTime) : that.orderTime != null) return false;
        if (errorCode != null ? !errorCode.equals(that.errorCode) : that.errorCode != null) return false;
        if (errorMsg != null ? !errorMsg.equals(that.errorMsg) : that.errorMsg != null) return false;
        if (extension1 != null ? !extension1.equals(that.extension1) : that.extension1 != null) return false;
        if (extension2 != null ? !extension2.equals(that.extension2) : that.extension2 != null) return false;
        return !(extension3 != null ? !extension3.equals(that.extension3) : that.extension3 != null);

    }

    @Override
    public int hashCode() {
        int result;
        long temp;
        result = orderId != null ? orderId.hashCode() : 0;
        result = 31 * result + (phone != null ? phone.hashCode() : 0);
        temp = Double.doubleToLongBits(orderAmount);
        result = 31 * result + (int) (temp ^ (temp >>> 32));
        result = 31 * result + (bizNo != null ? bizNo.hashCode() : 0);
        result = 31 * result + (payType != null ? payType.hashCode() : 0);
        result = 31 * result + (xunleiId != null ? xunleiId.hashCode() : 0);
        result = 31 * result + (userShow != null ? userShow.hashCode() : 0);
        result = 31 * result + (xunleiPayId != null ? xunleiPayId.hashCode() : 0);
        result = 31 * result + (orderTime != null ? orderTime.hashCode() : 0);
        result = 31 * result + (errorCode != null ? errorCode.hashCode() : 0);
        result = 31 * result + (errorMsg != null ? errorMsg.hashCode() : 0);
        result = 31 * result + (extension1 != null ? extension1.hashCode() : 0);
        result = 31 * result + (extension2 != null ? extension2.hashCode() : 0);
        result = 31 * result + (extension3 != null ? extension3.hashCode() : 0);
        return result;
    }
}

==> dbservice-1.0.0-20170421.091207-8905-sources.jar: com/xunlei/channel/db/pojo/UserCannotPayOrders.java <==
package com.xunlei.channel.db.pojo;

/**
 * Created by ouyangjixin on 2016/5/18.
 */
public class UserCannotPayOrders extends AbstractBaseEntity{

    /**
	 * 
	 */
	private static final long serialVersionUID = -2515830251913011062L;
	private String orderId;
    private String phone;
    private int orderAmt;
    private String bizNo;

    private String payType;
    private String xunleiId;
    private String userShow;

    private String xunleiPayId;
    private String orderTime;
    private String errorCode;
    private String errorMsg;
    private String extension1;

    private String extension2;
    private String extension3;
    
    private String balanceDate;

    
    public String getBalanceDate() {
		return balanceDate;
	}

	public void setBalanceDate(String balanceDate) {
		this.balanceDate = balanceDate;
	}

	public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }


    public String getBizNo() {
        return bizNo;
    }

    public void setBizNo(String bizNo) {
        this.bizNo = bizNo;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getXunleiId() {
        return xunleiId;
    }

    public void setXunleiId(String xunleiId) {
        this.xunleiId = xunleiId;
    }

    public String getUserShow() {
        return userShow;
    }

    public void setUserShow(String userShow) {
        this.userShow = userShow;
    }

    public String getXunleiPayId() {
        return xunleiPayId;
    }

    public void setXunleiPayId(String xunleiPayId) {
        this.xunleiPayId = xunleiPayId;
    }

    public String getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(String orderTime) {
        this.orderTime = orderTime;
    }

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getExtension1() {
        return extension1;
    }

    public void setExtension1(String extension1) {
        this.extension1 = extension1;
    }

    public String getExtension2() {
        return extension2;
    }

    public void setExtension2(String extension2) {
        this.extension2 = extension2;
    }

    public String getExtension3() {
        return extension3;
    }

    public void setExtension3(String extension3) {
        this.extension3 = extension3;
    }

	public int getOrderAmt() {
		return orderAmt;
	}

	public void setOrderAmt(int orderAmt) {
		this.orderAmt = orderAmt;
	}

}
